@@ -3,8 +3,8 @@ package Socket;
 use strict;
 { use 5.006001; }
 
-our $VERSION = '2.024_03';
-our $XS_VERSION = $VERSION;   # A dev xs version needs to be global, not my
+our $VERSION = '2.027_04';
+our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -775,7 +775,7 @@ our @EXPORT_OK = qw(
 
 	IPPROTO_IP IPPROTO_IPV6 IPPROTO_RAW IPPROTO_ICMP IPPROTO_IGMP
 	IPPROTO_TCP IPPROTO_UDP IPPROTO_GRE IPPROTO_ESP IPPROTO_AH
-	IPPROTO_SCTP
+	IPPROTO_ICMPV6 IPPROTO_SCTP
 
 	IP_PMTUDISC_DO IP_PMTUDISC_DONT IP_PMTUDISC_PROBE IP_PMTUDISC_WANT
 
@@ -785,7 +785,8 @@ our @EXPORT_OK = qw(
 	TCP_FASTOPEN TCP_INFO TCP_INIT_CWND TCP_KEEPALIVE TCP_KEEPCNT
 	TCP_KEEPIDLE TCP_KEEPINTVL TCP_LINGER2 TCP_MAXRT TCP_MAXSEG
 	TCP_MD5SIG TCP_NODELAY TCP_NOOPT TCP_NOPUSH TCP_QUICKACK
-	TCP_SACK_ENABLE TCP_STDURG TCP_SYNCNT TCP_WINDOW_CLAMP
+	TCP_SACK_ENABLE TCP_STDURG TCP_SYNCNT TCP_USER_TIMEOUT
+	TCP_WINDOW_CLAMP
 
 	IN6ADDR_ANY IN6ADDR_LOOPBACK
 
